<?xml version="1.0" encoding="ISO-8859-1" standalone="yes"?>
<!--
The Apache Software License, Version 1.1

Copyright (c) 1999, 2000 The Apache Software Foundation.  All rights
reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in
   the documentation and/or other materials provided with the
   distribution.

3. The end-user documentation included with the redistribution, if
   any, must include the following acknowlegement:
      "This product includes software developed by the
       Apache Software Foundation (http://www.apache.org/)."
   Alternately, this acknowlegement may appear in the software itself,
   if and wherever such third-party acknowlegements normally appear.

4. The names "The Jakarta Project", "Ant", and "Apache Software
   Foundation" must not be used to endorse or promote products derived
   from this software without prior written permission. For written
   permission, please contact apache@apache.org.

5. Products derived from this software may not be called "Apache"
   nor may "Apache" appear in their names without prior written
   permission of the Apache Group.

THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
SUCH DAMAGE.
====================================================================

This software consists of voluntary contributions made by many
individuals on behalf of the Apache Software Foundation.  For more
information on the Apache Software Foundation, please see
<http://www.apache.org/>.
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xrn="http://xmlreleasenotes.free.fr" xmlns:redirect="org.apache.xalan.xslt.extensions.Redirect" extension-element-prefixes="redirect">
	<!--
	This file belongs to XMLReleaseNotes V0.14.0.
	-->
	<!--
	The aim of this stylesheet is to enable to generate multiple HTML pages, one per version.
	-->
	<xsl:import href="XMLReleaseNotes2HTML"/>
	<xsl:output method="html" indent="yes" standalone="yes" encoding="ISO-8859-1" omit-xml-declaration="yes"/>
	<!--
	Defines the directory all generated HTML pages will be written into.
	-->
	<xsl:param name="destination" select="'.'"/>
	<!--
	Indicates whether the release notes concern more than one component or not.
	-->
	<xsl:param name="multipleComponents"/>
	<!--
	Defines a title that will be used on the overview summary page (the one that gathers all components).
	-->
	<xsl:param name="titleText" select="'All Components'"/>
	<!--
	The header text used, and displayed at the top navigation level.
	-->
	<xsl:param name="headerText"/>
	<!--
	The footer text used, and displayed at the bottom navigation level.
	-->
	<xsl:param name="footerText"/>
	<xsl:template match="/Components">
		<xsl:call-template name="print-overview-frame"/>
		<xsl:call-template name="print-allreleases-frame"/>
		<xsl:call-template name="print-overview-summary"/>
		<xsl:call-template name="print-about-doc"/>
		<xsl:call-template name="printIndexPage"/>
		<xsl:for-each select="*">
			<xsl:call-template name="printComponentSummaryPage"/>
			<xsl:call-template name="printComponentFeaturesPage"/>
		</xsl:for-each>
	</xsl:template>
	<!--
	Prints the HTML index page.
	The top XML element 'Components' contains 'xrn:ReleaseNotes' elements, but cannot be referenced as is, but should be referenced as '*'!
	-->
	<xsl:template name="printIndexPage">
		<xsl:variable name="releaseFramesetFilePath">
			<xsl:call-template name="_computeHTMLXRNReleaseFramesetFilePath"/>
		</xsl:variable>
		<xsl:variable name="releaseVersionFileName">
			<xsl:call-template name="_computeHTMLXRNReleaseVersionsFileName"/>
		</xsl:variable>
		<redirect:write file="{$destination}/index.html">
			<html>
				<head>
					<title>XRN multi-components index page</title>
					<xsl:call-template name="_printMeta"/>
					<frameset cols="20%,80%">
						<frameset rows="30%,70%">
							<frame src="overview-frame.html" name="componentListFrame"/>
							<frame src="allreleases-frame.html" name="releaseListFrame"/>
						</frameset>
						<frame src="overview-summary.html" name="releaseFrame"/>
					</frameset>
					<xsl:call-template name="_printNoFrameMessage"/>
				</head>
			</html>
		</redirect:write>
	</xsl:template>
	<!--
	Prints the HTML page that displays all component.
	The current node should be the 'Components' top-level node.
	-->
	<xsl:template name="print-overview-summary">
		<redirect:write file="{$destination}/overview-summary.html">
			<html>
				<xsl:call-template name="_printHead">
					<xsl:with-param name="title">XRN multi-components overview page</xsl:with-param>
				</xsl:call-template>
				<body>
					<xsl:call-template name="_printNavigation">
						<xsl:with-param name="location" select="'overview'"/>
					</xsl:call-template>
					<center>
						<h2>
							<xsl:value-of select="$titleText" disable-output-escaping="yes"/>
						</h2>
					</center>
					<table border="1" cellpadding="3" cellspacing="0" width="100%">
						<tbody>
							<tr bgcolor="#CCCCFF" class="TableHeadingColor">
								<td colspan="2">
									<font size="+2">
										<b>Components</b>
									</font>
								</td>
							</tr>
							<xsl:for-each select="*">
								<tr bgcolor="white" class="TableRowColor">
									<td width="20%">
										<b>
											<a>
												<xsl:attribute name="href"><xsl:call-template name="_computeHTMLXRNComponentSummaryFileName"/></xsl:attribute>
												<xsl:value-of select="@ID"/>
											</a>
										</b>
									</td>
									<td>
										<xsl:choose>
											<xsl:when test="Summary">
												<xsl:value-of select="Summary"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:text>&#160;</xsl:text>
											</xsl:otherwise>
										</xsl:choose>
									</td>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
					<p>
						<xsl:text>&#160;</xsl:text>
					</p>
					<hr/>
					<xsl:call-template name="_printNavigation">
						<xsl:with-param name="forFooter" select="1"/>
						<xsl:with-param name="location" select="'overview'"/>
					</xsl:call-template>
				</body>
			</html>
		</redirect:write>
	</xsl:template>
	<!--
	Prints the HTML frame that displays all component releases.
	The current node should be the 'Components' top-level node.
	-->
	<xsl:template name="print-allreleases-frame">
		<redirect:write file="{$destination}/allreleases-frame.html">
			<html>
				<xsl:call-template name="_printHead">
					<xsl:with-param name="title">XRN multi-components all-releases page</xsl:with-param>
				</xsl:call-template>
				<body>
					<table border="0" width="100%">
						<tbody>
							<tr>
								<td>
									<font size="+1" class="FrameHeadingFont">All Releases</font>
									<font class="FrameItemFont">
										<br/>
										<xsl:for-each select="*/Releases/Release">
											<a target="releaseFrame">
												<xsl:attribute name="href"><xsl:call-template name="_computeHTMLXRNReleaseContentFileName"/></xsl:attribute>
												<xsl:value-of select="../../@ID"/>
												<xsl:text>&#160;</xsl:text>
												<xsl:value-of select="@version"/>
											</a>
											<br/>
										</xsl:for-each>
									</font>
								</td>
							</tr>
						</tbody>
					</table>
				</body>
			</html>
		</redirect:write>
	</xsl:template>
	<!--
	Prints the HTML frame that displays all components.
	The current node should be the 'Components' top-level node.
	-->
	<xsl:template name="print-overview-frame">
		<redirect:write file="{$destination}/overview-frame.html">
			<html>
				<xsl:call-template name="_printHead">
					<xsl:with-param name="title">XRN multi-components all components frame</xsl:with-param>
				</xsl:call-template>
				<body>
					<font class="FrameItemFont">
						<a href="allreleases-frame.html" target="releaseListFrame">All Releases</a>
					</font>
					<p>
						<font size="+1" class="FrameHeadingFont">Components</font>
						<br/>
						<xsl:for-each select="*">
							<font class="FrameItemFont">
								<a target="releaseListFrame">
									<xsl:attribute name="href"><xsl:call-template name="_computeHTMLXRNReleaseVersionsFileName"/></xsl:attribute>
									<xsl:value-of select="@ID"/>
								</a>
							</font>
							<br/>
						</xsl:for-each>
					</p>
				</body>
			</html>
		</redirect:write>
	</xsl:template>
	<!--
	Prints the HTML about page.
	-->
	<xsl:template name="print-about-doc">
		<redirect:write file="{$destination}/about-doc.html">
			<html>
				<xsl:call-template name="_printHead">
					<xsl:with-param name="title">XRN about page</xsl:with-param>
				</xsl:call-template>
				<body>
					<xsl:call-template name="_printNavigation">
						<xsl:with-param name="location" select="'about'"/>
					</xsl:call-template>
					<center>
						<h1>About XML Release Notes (XRN)</h1>You can find some more information about this tool <a href="http://xmlreleasenotes.free.fr">here</a>.</center>
					<br/>
					<hr/>
					<xsl:call-template name="_printNavigation">
						<xsl:with-param name="forFooter" select="1"/>
						<xsl:with-param name="location" select="'about'"/>
					</xsl:call-template>
				</body>
			</html>
		</redirect:write>
	</xsl:template>
	<xsl:template match="xrn:ReleaseNotes">
		<xsl:call-template name="_checkVersion"/>
		<xsl:choose>
			<xsl:when test="$multipleComponents">
				<xsl:call-template name="printMutipleComponents"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="printSingleComponent"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--
	Prints the all the HTML pages when multiple pages are being asked for a single component.
	The current node should be the top 'ReleaseNotes' XML element.
	-->
	<xsl:template name="printSingleComponent">
		<xsl:call-template name="printComponentReleaseNotesContent"/>
		<xsl:call-template name="printComponentVersionsPage"/>
		<xsl:variable name="releaseVersionFileName">
			<xsl:call-template name="_computeHTMLXRNReleaseVersionsFileName"/>
		</xsl:variable>
		<xsl:variable name="releaseFramesetFilePath">
			<xsl:call-template name="_computeHTMLXRNReleaseFramesetFilePath"/>
		</xsl:variable>
		<xsl:for-each select="Releases/Release[1]">
			<xsl:variable name="releaseContentFileName">
				<xsl:call-template name="_computeHTMLXRNReleaseContentFileName"/>
			</xsl:variable>
			<!--redirect:write file="{$releaseFramesetFilePath}"-->
			<html>
				<head>
					<title>XRN frameset of component <xsl:value-of select="../../@ID"/>
					</title>
					<xsl:call-template name="_printMeta"/>
					<frameset cols="15%,85%">
						<frame name="versionsFrame" src="{$releaseVersionFileName}"/>
						<frame name="releaseFrame" src="{$releaseContentFileName}"/>
					</frameset>
					<xsl:call-template name="_printNoFrameMessage"/>
				</head>
			</html>
			<!--/redirect:write-->
		</xsl:for-each>
	</xsl:template>
	<!--
	Prints the all the HTML pages of a component when mutiple components are concerned.
	The current node should be the top 'ReleaseNotes' XML element.
	-->
	<xsl:template name="printMutipleComponents">
		<xsl:call-template name="printComponentReleaseNotesContent"/>
		<xsl:call-template name="printComponentVersionsPage"/>
	</xsl:template>
	<!--
	Prints the HTML pages - one per version - that shows the release notes of each version of the component.
	The curent node should be the top XRN 'ReleaseNotes' XML element.
	-->
	<xsl:template name="printComponentReleaseNotesContent">
		<xsl:variable name="componentOverviewURL">
			<xsl:call-template name="_computeHTMLXRNComponentSummaryFileName"/>
		</xsl:variable>
		<xsl:variable name="componentFeaturesURL">
			<xsl:call-template name="_computeHTMLXRNComponentFeaturesFileName"/>
		</xsl:variable>
		<xsl:for-each select="Releases/Release">
			<xsl:variable name="releaseContentFilePath">
				<xsl:call-template name="_computeHTMLXRNReleaseContentFilePath"/>
			</xsl:variable>
			<redirect:write file="{$releaseContentFilePath}">
				<html>
					<xsl:call-template name="_printHead">
						<xsl:with-param name="title">Release Notes content of <xsl:value-of select="../../@ID"/> and for version <xsl:value-of select="@version"/>
						</xsl:with-param>
					</xsl:call-template>
					<body>
						<xsl:variable name="previous_url">
							<xsl:if test="count(following-sibling::Release) > 0">
								<xsl:for-each select="(following-sibling::Release)[1]">
									<xsl:call-template name="_computeHTMLXRNReleaseContentFileName"/>
								</xsl:for-each>
							</xsl:if>
						</xsl:variable>
						<xsl:variable name="next_url">
							<xsl:if test="count(preceding-sibling::Release) > 0">
								<xsl:for-each select="(preceding-sibling::Release)[last()]">
									<xsl:call-template name="_computeHTMLXRNReleaseContentFileName"/>
								</xsl:for-each>
							</xsl:if>
						</xsl:variable>
						<xsl:if test="$multipleComponents">
							<xsl:call-template name="_printNavigation">
								<xsl:with-param name="location" select="'release'"/>
								<xsl:with-param name="component_url" select="$componentOverviewURL"/>
								<xsl:with-param name="feature_url" select="$componentFeaturesURL"/>
								<xsl:with-param name="previous_url" select="$previous_url"/>
								<xsl:with-param name="next_url" select="$next_url"/>
							</xsl:call-template>
						</xsl:if>
						<span class="releaseNotes">
							<xsl:call-template name="_printRelease"/>
							<xsl:if test="$banner">
								<div class="copyrightXRNInternal">
									<xsl:call-template name="_printBottomBanner"/>
								</div>
							</xsl:if>
						</span>
						<xsl:if test="$multipleComponents">
							<hr/>
							<xsl:call-template name="_printNavigation">
								<xsl:with-param name="forFooter" select="1"/>
								<xsl:with-param name="location" select="'release'"/>
								<xsl:with-param name="component_url" select="$componentOverviewURL"/>
								<xsl:with-param name="feature_url" select="$componentFeaturesURL"/>
								<xsl:with-param name="previous_url" select="$previous_url"/>
								<xsl:with-param name="next_url" select="$next_url"/>
							</xsl:call-template>
						</xsl:if>
					</body>
				</html>
			</redirect:write>
		</xsl:for-each>
	</xsl:template>
	<!--
	Prints the HTML page that shows all the component versions.
	The curent node should be the top XRN 'ReleaseNotes' XML element.
	-->
	<xsl:template name="printComponentVersionsPage">
		<xsl:variable name="releaseVersionFilePath">
			<xsl:call-template name="_computeHTMLXRNReleaseVersionsFilePath"/>
		</xsl:variable>
		<redirect:write file="{$releaseVersionFilePath}">
			<html>
				<xsl:call-template name="_printHead">
					<xsl:with-param name="title">XRN versions frame of component <xsl:value-of select="../../@ID"/>
					</xsl:with-param>
				</xsl:call-template>
				<body>
					<xsl:if test="$multipleComponents">
						<font size="+1" class="FrameTitleFont">
							<a target="releaseFrame">
								<xsl:attribute name="href"><xsl:call-template name="_computeHTMLXRNComponentSummaryFileName"/></xsl:attribute>
								<xsl:value-of select="@ID"/>
							</a>
						</font>
					</xsl:if>
					<table border="0" width="100%">
						<tbody>
							<tr>
								<td>
									<font size="+1" class="FrameHeadingFont">Releases</font>
									<font class="FrameItemFont">
										<br/>
										<xsl:for-each select="Releases/Release">
											<a target="releaseFrame">
												<xsl:attribute name="href"><xsl:call-template name="_computeHTMLXRNReleaseContentFileName"/></xsl:attribute>
												<xsl:value-of select="@version"/>
											</a>
											<br/>
										</xsl:for-each>
									</font>
								</td>
							</tr>
						</tbody>
					</table>
				</body>
			</html>
		</redirect:write>
	</xsl:template>
	<!--
	Prints the HTML page that presents the summary of the component (all releases displayed).
	The curent node should be the top XRN 'ReleaseNotes' XML element.
	-->
	<xsl:template name="printComponentSummaryPage">
		<xsl:variable name="componentSummaryFilePath">
			<xsl:call-template name="_computeHTMLXRNComponentSummaryFilePath"/>
		</xsl:variable>
		<xsl:variable name="componentFeaturesURL">
			<xsl:call-template name="_computeHTMLXRNComponentFeaturesFileName"/>
		</xsl:variable>
		<redirect:write file="{$componentSummaryFilePath}">
			<html>
				<xsl:call-template name="_printHead">
					<xsl:with-param name="title">XRN summary of component<xsl:value-of select="../../@ID"/>
					</xsl:with-param>
				</xsl:call-template>
				<body>
					<xsl:variable name="previous_url">
						<xsl:if test="count(preceding-sibling::*) > 0">
							<xsl:for-each select="(preceding-sibling::*)[last()]">
								<xsl:call-template name="_computeHTMLXRNComponentSummaryFileName"/>
							</xsl:for-each>
						</xsl:if>
					</xsl:variable>
					<xsl:variable name="next_url">
						<xsl:if test="count(following-sibling::*) > 0">
							<xsl:for-each select="(following-sibling::*)[1]">
								<xsl:call-template name="_computeHTMLXRNComponentSummaryFileName"/>
							</xsl:for-each>
						</xsl:if>
					</xsl:variable>
					<xsl:call-template name="_printNavigation">
						<xsl:with-param name="location" select="'component'"/>
						<xsl:with-param name="feature_url" select="$componentFeaturesURL"/>
						<xsl:with-param name="previous_url" select="$previous_url"/>
						<xsl:with-param name="next_url" select="$next_url"/>
					</xsl:call-template>
					<h2>
						<xsl:text>Component </xsl:text>
						<xsl:value-of select="@ID"/>
					</h2>
					<xsl:for-each select="Summary">
						<xsl:call-template name="_printContent"/>
					</xsl:for-each>
					<p>
						<table border="1" cellpadding="3" cellspacing="0" width="100%">
							<tbody>
								<tr bgcolor="#CCCCFF" class="TableHeadingColor">
									<td colspan="2">
										<font size="+2">
											<b>Release Summary</b>
										</font>
									</td>
								</tr>
								<xsl:for-each select="Releases/Release">
									<tr bgcolor="white" class="TableRowColor">
										<td width="15%">
											<b>
												<a>
													<xsl:attribute name="href"><xsl:call-template name="_computeHTMLXRNReleaseContentFileName"/></xsl:attribute>
													<xsl:value-of select="@version"/>
												</a>
											</b>
										</td>
										<td>
											<xsl:choose>
												<xsl:when test="Summary">
													<xsl:value-of select="Summary"/>
												</xsl:when>
												<xsl:otherwise>
													<xsl:text>&#160;</xsl:text>
												</xsl:otherwise>
											</xsl:choose>
										</td>
									</tr>
								</xsl:for-each>
							</tbody>
						</table>
					</p>
					<p>
						<xsl:text>&#160;</xsl:text>
					</p>
					<hr/>
					<xsl:call-template name="_printNavigation">
						<xsl:with-param name="forFooter" select="1"/>
						<xsl:with-param name="location" select="'component'"/>
						<xsl:with-param name="feature_url" select="$componentFeaturesURL"/>
						<xsl:with-param name="previous_url" select="$previous_url"/>
						<xsl:with-param name="next_url" select="$next_url"/>
					</xsl:call-template>
				</body>
			</html>
		</redirect:write>
	</xsl:template>
	<!--
	Prints the HTML page that gathers and displays all the component features.
	The curent node should be the top XRN 'ReleaseNotes' XML element.
	-->
	<xsl:template name="printComponentFeaturesPage">
		<xsl:variable name="componentFeaturesFilePath">
			<xsl:call-template name="_computeHTMLXRNComponentFeaturesFilePath"/>
		</xsl:variable>
		<xsl:variable name="componentOverviewURL">
			<xsl:call-template name="_computeHTMLXRNComponentSummaryFileName"/>
		</xsl:variable>
		<redirect:write file="{$componentFeaturesFilePath}">
			<html>
				<xsl:call-template name="_printHead">
					<xsl:with-param name="title">XRN features of component<xsl:value-of select="../../@ID"/>
					</xsl:with-param>
				</xsl:call-template>
				<body>
					<xsl:variable name="previous_url"/>
					<xsl:variable name="next_url"/>
					<xsl:call-template name="_printNavigation">
						<xsl:with-param name="location" select="'feature'"/>
						<xsl:with-param name="component_url" select="$componentOverviewURL"/>
						<xsl:with-param name="previous_url" select="$previous_url"/>
						<xsl:with-param name="next_url" select="$next_url"/>
					</xsl:call-template>
					<center>
						<h2>
							<b>
								<xsl:text>Features of component</xsl:text>
								<br/>
								<xsl:value-of select="@ID"/>
							</b>
						</h2>
					</center>
					<span class="releaseNotes">
						<table class="feature" width="100%">
							<tbody>
								<xsl:for-each select="Releases/Release/Features/Feature[(@ID) and (generate-id() = generate-id(key('feature_key', @ID)))]">
									<xsl:sort select="@ID"/>
									<tr class="featureHeader">
										<xsl:if test="@ID">
											<a>
												<xsl:attribute name="name"><xsl:call-template name="_computeFeatureHrefName"/></xsl:attribute>
											</a>
										</xsl:if>
										<td>
											<xsl:call-template name="_printFeatureFullIDInheritance"/>
										</td>
									</tr>
									<xsl:for-each select="../../../Release/Features/Feature[@ID = current()/@ID]">
										<xsl:variable name="componentReleaseURL">
											<xsl:call-template name="_computePointedFeatureHref"/>
										</xsl:variable>
										<xsl:call-template name="_printIndividualFeatureContent">
											<xsl:with-param name="additionalHTMLStuff">
												<font class="version" size="-2">
													<xsl:text>&#160;&#160;[</xsl:text>
													<a href="{$componentReleaseURL}">
														<xsl:value-of select="../../@version"/>
													</a>
													<xsl:text>]</xsl:text>
												</font>
											</xsl:with-param>
										</xsl:call-template>
									</xsl:for-each>
								</xsl:for-each>
								<xsl:for-each select="Releases/Release/Features/Feature[not(@ID)]">
									<xsl:variable name="componentReleaseURL">
										<xsl:call-template name="_computePointedFeatureHref"/>
									</xsl:variable>
									<tr class="featureHeader">
										<td>
											<xsl:text> </xsl:text>
										</td>
									</tr>
									<xsl:call-template name="_printIndividualFeatureContent">
										<xsl:with-param name="additionalHTMLStuff">
											<font class="version" size="-2">
												<xsl:text>&#160;&#160;[</xsl:text>
												<a href="{$componentReleaseURL}">
													<xsl:value-of select="../../@version"/>
												</a>
												<xsl:text>]</xsl:text>
											</font>
										</xsl:with-param>
									</xsl:call-template>
								</xsl:for-each>
							</tbody>
						</table>
					</span>
					<hr/>
					<xsl:call-template name="_printNavigation">
						<xsl:with-param name="forFooter" select="1"/>
						<xsl:with-param name="location" select="'feature'"/>
						<xsl:with-param name="previous_url" select="$previous_url"/>
						<xsl:with-param name="next_url" select="$next_url"/>
					</xsl:call-template>
				</body>
			</html>
		</redirect:write>
	</xsl:template>
	<!--
	Outputs the name and path (two next templates) of the HTML release frameset page, i.e. the one containing the left version and the right content HTML pages.
	The current node should be the top 'ReleaseNotes' XML element.
	-->
	<xsl:template name="_computeHTMLXRNReleaseFramesetFileName">
		<xsl:value-of select="@ID"/>
		<xsl:text>-frame.html</xsl:text>
	</xsl:template>
	<xsl:template name="_computeHTMLXRNReleaseFramesetFilePath">
		<xsl:value-of select="$destination"/>
		<xsl:text>/</xsl:text>
		<xsl:call-template name="_computeHTMLXRNReleaseFramesetFileName"/>
	</xsl:template>
	<!--
	Outputs the name and path (two next templates) of the HTML release content page.
	The current node should be the wanted 'Release' XML element.
	-->
	<xsl:template name="_computeHTMLXRNReleaseContentFileName">
		<xsl:value-of select="../../@ID"/>
		<xsl:text>-</xsl:text>
		<xsl:value-of select="@version"/>
		<xsl:text>.html</xsl:text>
	</xsl:template>
	<xsl:template name="_computeHTMLXRNReleaseContentFilePath">
		<xsl:value-of select="$destination"/>
		<xsl:text>/</xsl:text>
		<xsl:call-template name="_computeHTMLXRNReleaseContentFileName"/>
	</xsl:template>
	<!--
	Outputs the  the name and path (two next templates) of the HTML release version page.
	The current node should be the top 'ReleaseNotes' XML element.
	-->
	<xsl:template name="_computeHTMLXRNReleaseVersionsFileName">
		<xsl:value-of select="@ID"/>
		<xsl:text>-versions.html</xsl:text>
	</xsl:template>
	<xsl:template name="_computeHTMLXRNReleaseVersionsFilePath">
		<xsl:value-of select="$destination"/>
		<xsl:text>/</xsl:text>
		<xsl:call-template name="_computeHTMLXRNReleaseVersionsFileName"/>
	</xsl:template>
	<!--
	Outputs the  the name and path (two next templates) of the HTML page that provides a summary of the component.
	The current node should be the top 'ReleaseNotes' XML element.
	-->
	<xsl:template name="_computeHTMLXRNComponentSummaryFileName">
		<xsl:value-of select="@ID"/>
		<xsl:text>-summary.html</xsl:text>
	</xsl:template>
	<xsl:template name="_computeHTMLXRNComponentSummaryFilePath">
		<xsl:value-of select="$destination"/>
		<xsl:text>/</xsl:text>
		<xsl:call-template name="_computeHTMLXRNComponentSummaryFileName"/>
	</xsl:template>
	<!--
	Outputs the  the name and path (two next templates) of the HTML page that describes and gathers all component features.
	The current node should be the top 'ReleaseNotes' XML element.
	-->
	<xsl:template name="_computeHTMLXRNComponentFeaturesFileName">
		<xsl:value-of select="@ID"/>
		<xsl:text>-feature.html</xsl:text>
	</xsl:template>
	<xsl:template name="_computeHTMLXRNComponentFeaturesFilePath">
		<xsl:value-of select="$destination"/>
		<xsl:text>/</xsl:text>
		<xsl:call-template name="_computeHTMLXRNComponentFeaturesFileName"/>
	</xsl:template>
	<!--
	Prints the navigational part of a page.
	-->
	<xsl:template name="_printNavigation">
		<xsl:param name="forFooter"/>
		<xsl:param name="location"/>
		<xsl:param name="component_url"/>
		<xsl:param name="feature_url"/>
		<xsl:param name="previous_url"/>
		<xsl:param name="next_url"/>
		<table border="0" width="100%" cellpadding="1" cellspacing="0">
			<tbody>
				<tr>
					<td colspan="2" bgcolor="#EEEEFF" class="NavBarCell1">
						<table border="0" cellpadding="0" cellspacing="3">
							<tbody>
								<tr align="center" valing="top">
									<td>
										<xsl:call-template name="_printNavigationItem">
											<xsl:with-param name="location" select="'overview'"/>
											<xsl:with-param name="compared_location" select="$location"/>
											<xsl:with-param name="text" select="'Overview'"/>
											<xsl:with-param name="url" select="'overview-summary.html'"/>
										</xsl:call-template>
									</td>
									<td>
										<xsl:call-template name="_printNavigationItem">
											<xsl:with-param name="location" select="'component'"/>
											<xsl:with-param name="compared_location" select="$location"/>
											<xsl:with-param name="text" select="'Component'"/>
											<xsl:with-param name="url" select="$component_url"/>
										</xsl:call-template>
									</td>
									<td>
										<xsl:call-template name="_printNavigationItem">
											<xsl:with-param name="location" select="'release'"/>
											<xsl:with-param name="compared_location" select="$location"/>
											<xsl:with-param name="text" select="'Release'"/>
										</xsl:call-template>
									</td>
									<td>
										<xsl:call-template name="_printNavigationItem">
											<xsl:with-param name="location" select="'feature'"/>
											<xsl:with-param name="compared_location" select="$location"/>
											<xsl:with-param name="text" select="'Feature'"/>
											<xsl:with-param name="url" select="$feature_url"/>
										</xsl:call-template>
									</td>
									<td>
										<xsl:call-template name="_printNavigationItem">
											<xsl:with-param name="location" select="'about'"/>
											<xsl:with-param name="compared_location" select="$location"/>
											<xsl:with-param name="text" select="'About'"/>
											<xsl:with-param name="url" select="'about-doc.html'"/>
										</xsl:call-template>
									</td>
								</tr>
							</tbody>
						</table>
					</td>
					<td align="right" valing="top" rowspan="3">
						<em>
							<xsl:choose>
								<xsl:when test="$forFooter">
									<xsl:value-of select="$footerText" disable-output-escaping="yes"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$headerText" disable-output-escaping="yes"/>
								</xsl:otherwise>
							</xsl:choose>
						</em>
					</td>
				</tr>
				<tr>
					<td bgcolor="white" class="NavBarCell2">
						<font size="-2">
							<xsl:choose>
								<xsl:when test="$previous_url and $previous_url != ''">
									<a href="{$previous_url}">
										<b>
											<xsl:text>&#160;PREV&#160;&#160;</xsl:text>
										</b>
									</a>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>&#160;PREV&#160;&#160;</xsl:text>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:choose>
								<xsl:when test="$next_url and $next_url != ''">
									<a href="{$next_url}">
										<b>
											<xsl:text>&#160;NEXT&#160;&#160;</xsl:text>
										</b>
									</a>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>NEXT</xsl:text>
								</xsl:otherwise>
							</xsl:choose>
						</font>
					</td>
					<td bgcolor="white" class="NavBarCell2"/>
				</tr>
			</tbody>
		</table>
		<hr/>
	</xsl:template>
	<!--
	Prints a  navigation item.
	-->
	<xsl:template name="_printNavigationItem">
		<xsl:param name="location"/>
		<xsl:param name="compared_location"/>
		<xsl:param name="text"/>
		<xsl:param name="url"/>
		<xsl:variable name="top_td_class_unselected">NavBarCell1</xsl:variable>
		<xsl:variable name="top_td_class_selected">NavBarCell1Rev</xsl:variable>
		<xsl:variable name="top_td_bgcolor_unselected">#EEEEFF</xsl:variable>
		<xsl:variable name="top_td_bgcolor_selected">#FFFFFF</xsl:variable>
		<xsl:attribute name="class"><xsl:choose><xsl:when test="$location = $compared_location"><xsl:value-of select="$top_td_class_selected"/></xsl:when><xsl:otherwise><xsl:value-of select="$top_td_class_unselected"/></xsl:otherwise></xsl:choose></xsl:attribute>
		<xsl:attribute name="bgcolor"><xsl:choose><xsl:when test="$location = $compared_location"><xsl:value-of select="$top_td_bgcolor_selected"/></xsl:when><xsl:otherwise><xsl:value-of select="$top_td_bgcolor_unselected"/></xsl:otherwise></xsl:choose></xsl:attribute>
		<xsl:variable name="top_td_font_class_unselected">NavBarFont1</xsl:variable>
		<xsl:variable name="top_td_font_class_selected">NavBarFont1Rev</xsl:variable>
		<font>
			<xsl:attribute name="class"><xsl:choose><xsl:when test="$location = $compared_location"><xsl:value-of select="$top_td_font_class_selected"/></xsl:when><xsl:otherwise><xsl:value-of select="$top_td_font_class_unselected"/></xsl:otherwise></xsl:choose></xsl:attribute>
			<xsl:choose>
				<xsl:when test="$location = $compared_location">
					<b>
						<xsl:copy-of select="$text"/>
					</b>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="$url">
							<a href="{$url}">
								<b>
									<xsl:copy-of select="$text"/>
								</b>
							</a>
						</xsl:when>
						<xsl:otherwise>
							<xsl:copy-of select="$text"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:text>&#160;</xsl:text>
		</font>
	</xsl:template>
	<!--
	Prints the message when the browser does not support frames.
	-->
	<xsl:template name="_printNoFrameMessage">
		<noframes>
			<h2>Frame Alert</h2>
			<p>This document is designed to be viewed using the frames feature. If you see this message, you are using a non-frame-capable web client.</p>
		</noframes>
	</xsl:template>
	<!--
	Overwrites the defaut one.
	-->
	<xsl:template name="_printContent">
		<xsl:choose>
			<xsl:when test="@contentType = 'html'">
				<xsl:choose>
					<!--This is performed because of a weird bug in Xalan implementation...-->
					<xsl:when test="$XSLTImplementation = 'org.apache.xalan.transformer.TransformerImpl'">
						<xsl:message>The Xalan XSLT implementation does not support the '@contentType='html'' feature</xsl:message>
						<xsl:value-of select="."/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="@contentType = 'process'">
				<!--Not possible for the moment, we'll see how to do that for better framework integration...-->
				<xsl:apply-templates/>
			</xsl:when>
			<xsl:when test="not(text())"/>
			<xsl:otherwise>
				<xsl:value-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--
	Overwrites the defaut one.
	-->
	<xsl:template name="_computePointedFeatureHref">
		<xsl:for-each select="(../..)[1]">
			<xsl:call-template name="_computeHTMLXRNReleaseContentFileName"/>
		</xsl:for-each>
		<xsl:text>#</xsl:text>
		<xsl:value-of select="../../@version"/>
		<xsl:text>_</xsl:text>
		<xsl:value-of select="@ID"/>
	</xsl:template>
	<!--
	Overwrites the defaut one.
	-->
	<xsl:template name="_printFeatureID">
		<a>
			<xsl:attribute name="href"><xsl:call-template name="_computeFeatureHref"/></xsl:attribute>
			<xsl:value-of select="@ID"/>
		</a>
	</xsl:template>
	<!--
	This templates outputs the integral inheritance of a feature.
	The current node should be one of the 'Features/Feature' (with same 'ID' attribute) XML element for which the inheritance is asked for.
	-->
	<xsl:template name="_printFeatureFullIDInheritance">
		<xsl:if test="@ID">
			<span class="visualNoPrint">
				<span class="featureID">
					<xsl:text>&lt;</xsl:text>
					<xsl:value-of select="@ID"/>
					<xsl:text>&gt;</xsl:text>
					<xsl:if test="../../../Release/Features/Feature[@ID = current()/@ID]">
						<xsl:text>&#160;&#160;</xsl:text>
						<font class="version" size="-2">
							<xsl:for-each select="../../../Release/Features/Feature[@ID = current()/@ID]">
								<xsl:if test="count(preceding-sibling::Feature[@ID = current()/@ID]) = 0">
									<a>
										<xsl:attribute name="href"><xsl:call-template name="_computePointedFeatureHref"/></xsl:attribute>
										<xsl:text>[</xsl:text>
										<xsl:value-of select="../../@version"/>
										<xsl:text>]</xsl:text>
									</a>
									<xsl:if test="position() != last()">
										<xsl:text>, </xsl:text>
									</xsl:if>
								</xsl:if>
							</xsl:for-each>
						</font>
					</xsl:if>
					<br/>
				</span>
			</span>
		</xsl:if>
	</xsl:template>
	<!--
	Prints the name (after the # in the URL) of the feature full description, so that it can be referenced via an HTML anchor.
	The current node must be the 'Feature' XML element on which the reference is being computed.
	-->
	<xsl:template name="_computeFeatureHrefName">
		<xsl:choose>
			<xsl:when test="@ID">
				<xsl:value-of select="@ID"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="generate-id()"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--
	Prints the URL of feature full description, so that it can be referenced via an HTML anchor.
	The current node must be the 'Feature' XML element on which the reference is being computed.
	-->
	<xsl:template name="_computeFeatureHref">
		<xsl:for-each select="(../../../..)[1]">
			<xsl:call-template name="_computeHTMLXRNComponentFeaturesFileName"/>
		</xsl:for-each>
		<xsl:text>#</xsl:text>
		<xsl:call-template name="_computeFeatureHrefName"/>
	</xsl:template>
</xsl:stylesheet>
